# kiwi-platform-py

[![CircleCI](https://circleci.com/gh/kiwicom/kiwi-platform-py.svg?style=svg)](https://circleci.com/gh/kiwicom/kiwi-platform-py)
[![codecov](https://codecov.io/gh/kiwicom/kiwi-platform-py/branch/master/graph/badge.svg)](https://codecov.io/gh/kiwicom/kiwi-platform-py)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/7594931404704cdc88d214f6b8898735)](https://www.codacy.com/app/bence/kiwi-platform-py?utm_source=github.com&utm_medium=referral&utm_content=kiwicom/kiwi-platform-py&utm_campaign=Badge_Grade)
[![GitHub tag (latest SemVer)](https://img.shields.io/github/tag/kiwicom/kiwi-platform-py.svg)](https://github.com/kiwicom/kiwi-platform-py/tags)

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kiwi-platform.svg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-black.svg)](https://github.com/ambv/black)

Company standards as code for Kiwi.com

## Installation

Install with `pip install kiwi-platform`.

## Contributing

1. Check for open issues or open a fresh issue to start a discussion
2. Fork [the repository](https://github.com/kiwicom/kiwi-platform-py) on GitHub.
3. Send a pull request with your code!

Merging will require a test which shows that the bug was fixed,
or that the feature works as expected.
Feel free to open a draft pull request though without such a test
and ask for help with writing it if you're not sure how to.
